==> shopweb-check-sdk-1.7.5-20250720.012653-7-sources.jar: com/ovopark/check/Vo/SceneVo.java <==
package com.ovopark.check.Vo;

import java.io.Serializable;

/**
 * 
 * 场景表Po
 * @author starfox
 */
public class SceneVo implements Serializable {

	private static final long serialVersionUID = 1L;
	
	/** ID */
	private Integer id;
	/**部门id*/
	private Integer depId;
	/**模板id*/
	private Integer sceneModel;
	/**模板name*/
	private String sceneName;
	/** 设备id */
	private Integer deviceId;
	/** 预置位编号 */
	private Integer presetNo;
	/**标准图*/
	private String standardUrl;
	/**默认图*/
	private String defaultUrl;
	/**无效场景*/
	private Integer isDisabled=0;//1:不适用 0:适用 默认适用
	/**是否是扩展预置位*/
	private Integer isExtended=0;
	private Integer toUserId;//扩展预置位的目标用户
	/**预置位说明*/
	private String description;
	/**
	 * 是否还在使用，该字段用来防止用户误删除预置位
	 */
	private Boolean valid = true;
	
	private  int status;//旧状态
	private Integer state;//新状态
	
	private String preName;//临时用，app版本更新后就删除
	/** 预置位编号 为了保持向前兼容 */
	private Integer preId;
	private Integer isWatching = 0;
	private Integer isValid;

	public Integer getIsValid() {
		return isValid;
	}

	public void setIsValid(Integer isValid) {
		this.isValid = isValid;
	}

	public Integer getId() {
		return id;
	}
	public void setId(Integer id) {
		this.id = id;
	}
	public Integer getDepId() {
		return depId;
	}
	public void setDepId(Integer depId) {
		this.depId = depId;
	}
	public Integer getSceneModel() {
		return sceneModel;
	}
	public void setSceneModel(Integer sceneModel) {
		this.sceneModel = sceneModel;
	}
	public String getSceneName() {
		return sceneName;
	}
	public void setSceneName(String sceneName) {
		this.sceneName = sceneName;
	}
	public Integer getDeviceId() {
		return deviceId;
	}
	public void setDeviceId(Integer deviceId) {
		this.deviceId = deviceId;
	}
	public Integer getPresetNo() {
		return presetNo;
	}
	public void setPresetNo(Integer presetNo) {
		this.presetNo = presetNo;
	}
	public String getStandardUrl() {
		return standardUrl;
	}
	public void setStandardUrl(String standardUrl) {
		this.standardUrl = standardUrl;
	}
	public String getDefaultUrl() {
		return defaultUrl;
	}
	public void setDefaultUrl(String defaultUrl) {
		this.defaultUrl = defaultUrl;
	}
	public Integer getIsDisabled() {
		return isDisabled;
	}
	public void setIsDisabled(Integer isDisabled) {
		this.isDisabled = isDisabled;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public Boolean getValid() {
		return valid;
	}
	public void setValid(Boolean valid) {
		this.valid = valid;
	}
	public int getStatus() {
		return status;
	}
	public void setStatus(int status) {
		this.status = status;
	}
	public Integer getState() {
		return state;
	}
	public void setState(Integer state) {
		this.state = state;
	}
	public Integer getIsExtended() {
		return isExtended;
	}
	public void setIsExtended(Integer isExtended) {
		this.isExtended = isExtended;
	}
	public Integer getToUserId() {
		return toUserId;
	}
	public void setToUserId(Integer toUserId) {
		this.toUserId = toUserId;
	}
	public String getPreName() {
		return preName;
	}
	public void setPreName(String preName) {
		this.preName = preName;
	}
	public Integer getPreId() {
		return preId;
	}
	public void setPreId(Integer preId) {
		this.preId = preId;
	}
	public Integer getIsWatching() {
		return isWatching;
	}
	public void setIsWatching(Integer isWatching) {
		this.isWatching = isWatching;
	}
}

==> shopweb-check-sdk-1.8.0-20251103.032403-3-sources.jar: com/ovopark/check/Vo/SceneVo.java <==
package com.ovopark.check.Vo;

import java.io.Serializable;

/**
 * 
 * 场景表Po
 * @author starfox
 */
public class SceneVo implements Serializable {

	private static final long serialVersionUID = 1L;
	
	/** ID */
	private Integer id;
	/**部门id*/
	private Integer depId;
	/**模板id*/
	private Integer sceneModel;
	/**模板name*/
	private String sceneName;
	/** 设备id */
	private Long deviceId;
	/** 预置位编号 */
	private Integer presetNo;
	/**标准图*/
	private String standardUrl;
	/**默认图*/
	private String defaultUrl;
	/**无效场景*/
	private Integer isDisabled=0;//1:不适用 0:适用 默认适用
	/**是否是扩展预置位*/
	private Integer isExtended=0;
	private Integer toUserId;//扩展预置位的目标用户
	/**预置位说明*/
	private String description;
	/**
	 * 是否还在使用，该字段用来防止用户误删除预置位
	 */
	private Boolean valid = true;
	
	private  int status;//旧状态
	private Integer state;//新状态
	
	private String preName;//临时用，app版本更新后就删除
	/** 预置位编号 为了保持向前兼容 */
	private Integer preId;
	private Integer isWatching = 0;
	private Integer isValid;

	public Integer getIsValid() {
		return isValid;
	}

	public void setIsValid(Integer isValid) {
		this.isValid = isValid;
	}

	public Integer getId() {
		return id;
	}
	public void setId(Integer id) {
		this.id = id;
	}
	public Integer getDepId() {
		return depId;
	}
	public void setDepId(Integer depId) {
		this.depId = depId;
	}
	public Integer getSceneModel() {
		return sceneModel;
	}
	public void setSceneModel(Integer sceneModel) {
		this.sceneModel = sceneModel;
	}
	public String getSceneName() {
		return sceneName;
	}
	public void setSceneName(String sceneName) {
		this.sceneName = sceneName;
	}
	public Long getDeviceId() {
		return deviceId;
	}
	public void setDeviceId(Long deviceId) {
		this.deviceId = deviceId;
	}
	public Integer getPresetNo() {
		return presetNo;
	}
	public void setPresetNo(Integer presetNo) {
		this.presetNo = presetNo;
	}
	public String getStandardUrl() {
		return standardUrl;
	}
	public void setStandardUrl(String standardUrl) {
		this.standardUrl = standardUrl;
	}
	public String getDefaultUrl() {
		return defaultUrl;
	}
	public void setDefaultUrl(String defaultUrl) {
		this.defaultUrl = defaultUrl;
	}
	public Integer getIsDisabled() {
		return isDisabled;
	}
	public void setIsDisabled(Integer isDisabled) {
		this.isDisabled = isDisabled;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public Boolean getValid() {
		return valid;
	}
	public void setValid(Boolean valid) {
		this.valid = valid;
	}
	public int getStatus() {
		return status;
	}
	public void setStatus(int status) {
		this.status = status;
	}
	public Integer getState() {
		return state;
	}
	public void setState(Integer state) {
		this.state = state;
	}
	public Integer getIsExtended() {
		return isExtended;
	}
	public void setIsExtended(Integer isExtended) {
		this.isExtended = isExtended;
	}
	public Integer getToUserId() {
		return toUserId;
	}
	public void setToUserId(Integer toUserId) {
		this.toUserId = toUserId;
	}
	public String getPreName() {
		return preName;
	}
	public void setPreName(String preName) {
		this.preName = preName;
	}
	public Integer getPreId() {
		return preId;
	}
	public void setPreId(Integer preId) {
		this.preId = preId;
	}
	public Integer getIsWatching() {
		return isWatching;
	}
	public void setIsWatching(Integer isWatching) {
		this.isWatching = isWatching;
	}
}
